@@ -1,6 +1,7 @@
 from __future__ import print_function
 import sqlparse
-from parseutils import last_word, extract_tables
+from sqlparse.sql import Comparison
+from parseutils import last_word, extract_tables, find_prev_keyword
 
 
 def suggest_type(full_text, text_before_cursor):
@@ -11,8 +12,6 @@ def suggest_type(full_text, text_before_cursor):
     A scope for a column category will be a list of tables.
     """
 
-    #word_before_cursor = last_word(text_before_cursor,
-            #include='all_punctuations')
     word_before_cursor = last_word(text_before_cursor,
             include='most_punctuations')
 
@@ -41,15 +40,30 @@ def suggest_based_on_last_token(token, text_before_cursor, full_text):
     if isinstance(token, basestring):
         token_v = token
     else:
-        token_v = token.value
+        # If 'token' is a Comparison type such as
+        # 'select * FROM abc a JOIN def d ON a.id = d.'. Then calling
+        # token.value on the comparison type will only return the lhs of the
+        # comparison. In this case a.id. So we need to do token.tokens to get
+        # both sides of the comparison and pick the last token out of that
+        # list.
+        if isinstance(token, Comparison):
+            token_v = token.tokens[-1].value
+        else:
+            token_v = token.value
 
     if token_v.lower().endswith('('):
+        p = sqlparse.parse(text_before_cursor)[0]
+        if p.token_first().value.lower() == 'select':
+            # If the lparen is preceeded by a space chances are we're about to
+            # do a sub-select.
+            if last_word(text_before_cursor, 'all_punctuations').startswith('('):
+                return 'keywords', []
         return 'columns', extract_tables(full_text)
     if token_v.lower() in ('set', 'by', 'distinct'):
         return 'columns', extract_tables(full_text)
     elif token_v.lower() in ('select', 'where', 'having'):
         return 'columns-and-functions', extract_tables(full_text)
-    elif token_v.lower() in ('from', 'update', 'into', 'describe'):
+    elif token_v.lower() in ('from', 'update', 'into', 'describe', 'join'):
         return 'tables', []
     elif token_v in ('d',):  # \d
         return 'tables', []
@@ -61,15 +75,6 @@ def suggest_based_on_last_token(token, text_before_cursor, full_text):
     elif token_v.endswith('.'):
         current_alias = last_word(token_v[:-1])
         tables = extract_tables(full_text, include_alias=True)
-        return 'columns', [tables.get(current_alias)]
+        return 'columns', [tables.get(current_alias) or current_alias]
     else:
         return 'keywords', []
-
-def find_prev_keyword(sql):
-    if not sql.strip():
-        return None
-
-    for t in reversed(list(sqlparse.parse(sql)[0].flatten())):
-        if t.is_keyword or t.value == '(':
-            return t.value
-
